# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.6
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import DeviceServer
from DeviceServer.api.devices_api import DevicesApi  # noqa: E501
from DeviceServer.rest import ApiException


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self):
        self.api = DeviceServer.api.devices_api.DevicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_current(self):
        """Test case for get_current

        GET current reading of device  # noqa: E501
        """
        pass

    def test_get_device_device_id_buttons(self):
        """Test case for get_device_device_id_buttons

        GET all buttons for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_leds(self):
        """Test case for get_device_device_id_leds

        GET all leds for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_ports(self):
        """Test case for get_device_device_id_ports

        GET all ports for device  # noqa: E501
        """
        pass

    def test_get_device_device_id_temperature_ports(self):
        """Test case for get_device_device_id_temperature_ports

        GET all temperature ports for device  # noqa: E501
        """
        pass

    def test_get_device_id_port_index(self):
        """Test case for get_device_id_port_index

        GET status of port  # noqa: E501
        """
        pass

    def test_get_device_port_current(self):
        """Test case for get_device_port_current

        GET current reading of device Port  # noqa: E501
        """
        pass

    def test_get_device_port_voltage(self):
        """Test case for get_device_port_voltage

        GET voltage reading of device Port  # noqa: E501
        """
        pass

    def test_get_device_uuid(self):
        """Test case for get_device_uuid

        GET uuid from database  # noqa: E501
        """
        pass

    def test_get_devices(self):
        """Test case for get_devices

        GET list of devices  # noqa: E501
        """
        pass

    def test_get_devices_button(self):
        """Test case for get_devices_button

        GET state of button  # noqa: E501
        """
        pass

    def test_get_devices_index(self):
        """Test case for get_devices_index

        GET single device  # noqa: E501
        """
        pass

    def test_get_devices_led(self):
        """Test case for get_devices_led

        GET state of LED  # noqa: E501
        """
        pass

    def test_get_devices_temperature(self):
        """Test case for get_devices_temperature

        GET temperature reading  # noqa: E501
        """
        pass

    def test_get_fan_speed(self):
        """Test case for get_fan_speed

        GET device fan speed  # noqa: E501
        """
        pass

    def test_get_fan_target_temperature(self):
        """Test case for get_fan_target_temperature

        GET device fan target temperature  # noqa: E501
        """
        pass

    def test_get_fan_temperature(self):
        """Test case for get_fan_temperature

        GET device fan temperature  # noqa: E501
        """
        pass

    def test_get_firmware_version(self):
        """Test case for get_firmware_version

        GET Device Firmware Version  # noqa: E501
        """
        pass

    def test_get_message_from_rx_buffer(self):
        """Test case for get_message_from_rx_buffer

        GET message from RX table  # noqa: E501
        """
        pass

    def test_get_message_from_tx_buffer(self):
        """Test case for get_message_from_tx_buffer

        GET message from TX table  # noqa: E501
        """
        pass

    def test_get_port(self):
        """Test case for get_port

        GET status of port by id  # noqa: E501
        """
        pass

    def test_get_port_states(self):
        """Test case for get_port_states

        GET port states by port id  # noqa: E501
        """
        pass

    def test_get_ports(self):
        """Test case for get_ports

        GET status of all ports  # noqa: E501
        """
        pass

    def test_get_relay_state(self):
        """Test case for get_relay_state

        GET state of relay  # noqa: E501
        """
        pass

    def test_get_temperature_range(self):
        """Test case for get_temperature_range

        GET Temperature Range  # noqa: E501
        """
        pass

    def test_get_temperature_thresholds(self):
        """Test case for get_temperature_thresholds

        GET Temperature Thresholds  # noqa: E501
        """
        pass

    def test_get_voltage(self):
        """Test case for get_voltage

        GET voltage reading of device  # noqa: E501
        """
        pass

    def test_put_device(self):
        """Test case for put_device

        PUT Add device  # noqa: E501
        """
        pass

    def test_put_device_device_id_description(self):
        """Test case for put_device_device_id_description

        PUT a description for a Device  # noqa: E501
        """
        pass

    def test_put_device_device_id_name(self):
        """Test case for put_device_device_id_name

        PUT a name for a Device  # noqa: E501
        """
        pass

    def test_put_device_id_label(self):
        """Test case for put_device_id_label

        PUT a Port label  # noqa: E501
        """
        pass

    def test_put_device_port_module_led_state(self):
        """Test case for put_device_port_module_led_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_device_port_module_relay_state(self):
        """Test case for put_device_port_module_relay_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_devices_led_index(self):
        """Test case for put_devices_led_index

        PUT state of LED  # noqa: E501
        """
        pass

    def test_put_devices_ports(self):
        """Test case for put_devices_ports

        PUT state of port  # noqa: E501
        """
        pass

    def test_put_port_led_state(self):
        """Test case for put_port_led_state

        PUT state of Port LED  # noqa: E501
        """
        pass

    def test_put_port_port_id_label(self):
        """Test case for put_port_port_id_label

        PUT the label for a Port  # noqa: E501
        """
        pass

    def test_put_port_port_id_state_label(self):
        """Test case for put_port_port_id_state_label

        PUT state label  # noqa: E501
        """
        pass

    def test_put_port_states_port_id(self):
        """Test case for put_port_states_port_id

          # noqa: E501
        """
        pass

    def test_put_ports_pulse(self):
        """Test case for put_ports_pulse

        PUT port into state for period of time  # noqa: E501
        """
        pass

    def test_put_relay_state(self):
        """Test case for put_relay_state

          # noqa: E501
        """
        pass

    def test_put_serial_test_message(self):
        """Test case for put_serial_test_message

        Serial Message Test  # noqa: E501
        """
        pass

    def test_put_state_by_port_id(self):
        """Test case for put_state_by_port_id

        PUT state of port  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
