# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.0.6
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import DeviceServer
from DeviceServer.models.db_device_button import DbDeviceButton  # noqa: E501
from DeviceServer.rest import ApiException

class TestDbDeviceButton(unittest.TestCase):
    """DbDeviceButton unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DbDeviceButton
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = DeviceServer.models.db_device_button.DbDeviceButton()  # noqa: E501
        if include_optional :
            return DbDeviceButton(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435', 
                button_index = 1, 
                label = '', 
                button_id = ''
            )
        else :
            return DbDeviceButton(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
                button_index = 1,
                button_id = '',
        )

    def testDbDeviceButton(self):
        """Test DbDeviceButton"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
